@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011-2013 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2018 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -43,11 +43,16 @@
 #define MYSQL_SERVER 1
 #include <mysql_version.h>
 
-#ifdef MARIADB_BASE_VERSION
-#  define MRN_MARIADB_P 1
+#include <sql_plugin.h>
+#if MYSQL_VERSION_ID >= 50600
+#  include <my_default.h>
 #endif
 
-#include <sql_plugin.h>
+#ifdef MARIADB_BASE_VERSION
+#  define MRN_MARIADB_P 1
+#elif defined(FIRST_SUPPORTED_COMPRESSED_COLUMNS_VERSION)
+#  define MRN_PERCONA_P 1
+#endif
 
 #include <sql_const.h>
 #include <sql_class.h>
