@@ -1,7 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011-2020 Sutou Kouhei <kou@clear-code.com>
-  Copyright(C) 2020-2021 Horimoto Yasuhiro <horimoto@clear-code.com>
+  Copyright(C) 2011-2021  Sutou Kouhei <kou@clear-code.com>
+  Copyright(C) 2020-2021  Horimoto Yasuhiro <horimoto@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -396,8 +396,24 @@ typedef HASH mrn_table_def_cache_type;
 
 #if MYSQL_VERSION_ID >= 50706 && !defined(MRN_MARIADB_P)
 #  define MRN_HAVE_SPATIAL
+#  if MYSQL_VERSION_ID >= 80000
+#    define MRN_HAVE_SRID
+#    include <sql/gis/srid.h>
+using mrn_srid = gis::srid_t;
+#    define MRN_FIELD_GEOM_GET_SRID(field)      \
+  (field->get_srid().has_value() ?              \
+   field->get_srid().value() :                  \
+   0)
+#    define MRN_HAVE_SRS
+#  else
+using mrn_srid = uint32_t;
+#    define MRN_FIELD_GEOM_GET_SRID(field) 0
+#  endif
 #elif defined(HAVE_SPATIAL)
 #  define MRN_HAVE_SPATIAL
+#  define MRN_HAVE_SRID
+typedef uint mrn_srid;
+#    define MRN_FIELD_GEOM_GET_SRID(field) (field->get_srid())
 #endif
 
 #if MYSQL_VERSION_ID >= 50706 && !defined(MRN_MARIADB_P)
@@ -457,11 +473,26 @@ typedef HASH mrn_table_def_cache_type;
 #if MYSQL_VERSION_ID >= 80022 && !defined(MRN_MARIADB_P)
 #  define MRN_QUERY_BLOCK_HAS_LIMIT(query_block) \
   (query_block->has_limit())
+#elif MYSQL_VERSION_ID >= 100603
+#  define MRN_QUERY_BLOCK_HAS_LIMIT(query_block) \
+  (query_block->limit_params.explicit_limit)
 #else
 #  define MRN_QUERY_BLOCK_HAS_LIMIT(query_block) \
   (query_block->explicit_limit)
 #endif
 
+#if MYSQL_VERSION_ID >= 100603 && defined(MRN_MARIADB_P)
+#  define MRN_QUERY_BLOCK_SELECT_LIMIT(query_block) \
+  (query_block->limit_params.select_limit)
+#  define MRN_QUERY_BLOCK_OFFSET_LIMIT(query_block) \
+  (query_block->limit_params.offset_limit)
+#else
+#  define MRN_QUERY_BLOCK_SELECT_LIMIT(query_block) \
+  (query_block->select_limit)
+#  define MRN_QUERY_BLOCK_OFFSET_LIMIT(query_block) \
+  (query_block->offset_limit)
+#endif
+
 #if defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000
 #  if MYSQL_VERSION_ID >= 100504
 #    define mrn_init_sql_alloc(thd, name, mem_root)                     \
@@ -980,3 +1011,23 @@ typedef HASH mrn_table_def_cache_type;
                                (MYSQL_VERSION_ID >= 100509))
 #  define MRN_DBUG_TMP_USE_BITMAP_PP
 #endif
+
+#if defined(MRN_MARIADB_P) && (MYSQL_VERSION_ID >= 100603)
+#  define MRN_CHARSET_CSNAME(charset) \
+  ((charset)->cs_name.str)
+#  define MRN_CHARSET_NAME(charset) \
+  ((charset)->coll_name.str)
+#else
+#  define MRN_CHARSET_CSNAME(charset) \
+  ((charset)->csname)
+#  define MRN_CHARSET_NAME(charset) \
+  ((charset)->name)
+#endif
+
+#if MYSQL_VERSION_ID >= 100603 && defined(MRN_MARIADB_P)
+#  define MRN_MATCH_ITEM_FLAGS(match_item) \
+  ((match_item)->match_flags)
+#else
+#  define MRN_MATCH_ITEM_FLAGS(match_item) \
+  ((match_item)->flags)
+#endif
